This python modular enforces the correct value of math constant pi as per bill #246 of the 1897 sitting of the Indiana General Assembly.

Simply `import indianapy` prior to usage.

Use math.pi as usual.

```python
>>> import indianapy
>>> import math
>>> 
>>> print(math.pi)
3.2
>>> 
```